@@ -100,6 +100,7 @@ AmiDistributionConfigurationTypeDef = TypedDict(
     {
         "name": str,
         "description": str,
+        "targetAccountIds": List[str],
         "amiTags": Dict[str, str],
         "kmsKeyId": str,
         "launchPermission": "LaunchPermissionConfigurationTypeDef",
@@ -109,7 +110,14 @@ AmiDistributionConfigurationTypeDef = TypedDict(
 
 AmiTypeDef = TypedDict(
     "AmiTypeDef",
-    {"region": str, "image": str, "name": str, "description": str, "state": "ImageStateTypeDef"},
+    {
+        "region": str,
+        "image": str,
+        "name": str,
+        "description": str,
+        "state": "ImageStateTypeDef",
+        "accountId": str,
+    },
     total=False,
 )
 
@@ -231,7 +239,7 @@ EbsInstanceBlockDeviceSpecificationTypeDef = TypedDict(
         "kmsKeyId": str,
         "snapshotId": str,
         "volumeSize": int,
-        "volumeType": Literal["standard", "io1", "gp2", "sc1", "st1"],
+        "volumeType": Literal["standard", "io1", "io2", "gp2", "sc1", "st1"],
     },
     total=False,
 )
